@@ -1,7 +1,8 @@
 # -*- coding: utf-8 -*-
 from py_common_util.common.common_utils import CommonUtils
-import sys, os
-from skydl.model.impl.my_pytorch_model import MyPyTorchModel
+import sys
+import os
+from skydl.model.impl.my_pytorch.my_pytorch_model import MyPyTorchModel
 sys.path.append(os.path.abspath('%s/..' % sys.path[0]))
 
 
