@@ -155,7 +155,7 @@ if __name__ == "__main__":
     注意：当前程序main方法要运行在head node主机上，如果head node挂了，程序连不上plasma，则需要1. $ps -ef | grep ray, kill server.py, kill 僵尸ray_worker进程 2. $ray stop, 3. head node挂了不需要这步：remove /tmp/ray目录，4. 然后$ray start，5.再重新执行server.py
     """
     try:
-        redis_address = "192.168.83.111:6379"
+        redis_address = "localhost:6379"
         ray.init(redis_address=redis_address, ignore_reinit_error=True)
         print(ray.nodes())
         dispatcher.server = NewsServer.remote()
