@@ -4,7 +4,7 @@ import logging
 import traceback
 import time
 from py_common_util.common.date_utils import DateUtils
-from ray.experimental.streaming.streaming import Environment, DataStream
+from skydl.ray.experimental.streaming.streaming import Environment, DataStream
 from skydl.ray.experimental.ray_streaming_util import DefaultStreamingSource, DefaultStreamingEnvConfig
 
 # define logger
